package de.intevation.flys.client.shared.model;

import com.smartgwt.client.widgets.grid.ListGridRecord;


/**
 * The DistanceInfoRecord is a wrapper to put DistanceInfo objects into
 * a ListGrid.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class DistanceInfoRecord extends ListGridRecord {

    /** The artifact collection. */
    protected DistanceInfoObject distanceInfo;


    /**
     * The default constructor.
     *
     * @param info The distance info object.
     */
    public DistanceInfoRecord(DistanceInfoObject info) {
        this.distanceInfo = info;

        setDescription(info.getDescription());
        setFrom(info.getFrom());
        if (info.getTo() != null)
            setTo(info.getTo());
        else
            setTo(info.getFrom());
        setRiverside(info.getRiverside());
    }


    /**
     * Sets the creation time.
     *
     * @param creationTime The creation time.
     */
    public void setDescription(String description) {
        setAttribute("description", description);
    }


    /**
     * Returns the description.
     *
     * @return the description.
     */
    public String getDescription() {
        return getAttributeAsString("description");
    }


    public void setFrom(double from) {
        setAttribute("from", from);
    }


    public double getFrom() {
        return getAttributeAsDouble("from");
    }

    public void setTo(double to) {
        setAttribute("to", to);
    }


    public double getTo() {
        return getAttributeAsDouble("to");
    }


    public void setRiverside(String side) {
        setAttribute("riverside", side);
    }


    public String getRiverside() {
        return getAttributeAsString("riverside");
    }


    public DistanceInfoObject getDistanceInfo() {
        return distanceInfo;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
